/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file extras.h
 *
 * @type helper
 *
 * @description
 *
 * The extras are a collection of miscellaneous components that
 * assist in a standard look-and-feel for applications.
 */

#ifndef __rov_extras
#define __rov_extras


#ifdef __cplusplus
extern "C"
{
#endif

#ifndef __rov_main
#include "main.h"
#endif

/**
 * Makes infoboxes 3D. Note that this is deprecated, as the 3D logic is
 * automatically called.
 */
void infobox_3d(void);

/**
 * Creates a standard infobox.
 * @param name the name of the application.
 * @param purpose the purpose of the application.
 * @param author the author of the application.
 * @param version the version of the application.
 * @return the generated canvas.
 * @see create_licenseinfobox()
 * @see create_compileinfobox()
 */
canvas create_infobox(char *name,
		      char *purpose,
		      char *author,
		      char *version);

/**
 * Creates an info box with a license key.
 * @param name the name of the application.
 * @param purpose the purpose of the application.
 * @param author the author of the application.
 * @param version the version of the application.
 * @param license the license key for the application.
 * @return the generated canvas.
 * @see create_infobox()
 * @see create_compileinfobox()
 */
canvas create_licenseinfobox(char *name,
			     char *purpose,
			     char *author,
			     char *version,
			     char *license);

/**
 * Creates an info box with a compile version.
 * @param name the name of the application.
 * @param purpose the purpose of the application.
 * @param author the author of the application.
 * @param version the version of the application.
 * @param compile the compile version of the application.
 * @return the generated canvas.
 * @see create_infobox()
 * @see create_licenseinfobox()
 */
canvas create_compileinfobox(char *name,
			     char *purpose,
			     char *author,
			     char *version,
			     char *compile);


/**
 * Responds to a HelpRequest message with a string.
 * @param response the string to respond with.
 */
void return_help(char *response);

/**
 * Display error message.
 * @param fatal a flag indicating whether this is fatal or not
 * (non-zero is fatal).
 * @param pf_str printf-style string.
 * @param ... optional list of parameters.
 * @note This uses an internal error generation reporting that is
 * designed to be extendable in the same way that RISC OS 3.5+
 * error boxes are. As a result, it will look different on non
 * 3.5+ machines. If this is undesireable, then call swerr()
 * instead.
 * @see swerr()
 * @see message_box()
 */
void werr(int fatal,
	  char *pf_str,
	  ...);

/**
 * Display error message.
 * @param fatal a flag indicating whether this is fatal or not
 * (non-zero is fatal).
 * @param pf_str printf-style string.
 * @param ... optional list of parameters.
 * @note This differs from werr() in that it uses the standard error
 * reporting for the OS.
 * @see werr()
 * @see message_box()
 */
void swerr(int fatal,
	   char *pf_str,
	   ...);

/**
 * Displays a message.
 * @param flags flags for the message box.
 * @param title the title for the message box.
 * @param pf_str printf-style string.
 * @param ... optional list of parameters.
 * @return the button that was clicked to acknowledge the message box.
 * @note This uses the standard error box reporting for the OS to display
 * the message box.
 * @see werr()
 * @see swerr()
 * @see Message box flags
 */
int message_box(int flags,
		char *title,
		char *pf_str,
		...);

/**
 * Poll until first null event.
 * @note This must be called before main_poll (see main.h for information).
 */
void poll_init(void);

#ifdef OLDMENU_STYLE
menu msg_menu(char * , int, _rov_menuh, _rov_submenuh); /* Uses msgtrans to get the menu from */
 /* file - format : */
 /* foo00: < title > */
 /* foo01: < item #0 > */
 /* foo02: < item #1 > */
 /* ... Numbers are in decimal. */
menu msg_menuwriteable(char * , int, char * , char * , int_rov_menuh, _rov_submenuh);
								/* Uses msgtrans to get the menu from */
 /* file - format : */
 /* foo00: < title > */
 /* foo01: < item #0 > */
 /* foo02: < item #1 > */
 /* ... Numbers are in decimal. */
 /* Last one is writeable		 */
#else
/**
 * Create a menu from a messages file.
 * @param prefix the prefix for the menu held in the messages file.
 * @param items the number of items in the messages file.
 * @param ... two parameters, the first is the menu choose handler function,
 * the second is the sub-menu creation handler function.
 * @return the generated menu.
 * @note This function is prototyped in this way, as the handler functions
 * can have shortcuts if they do not require the full information passed
 * into them. See menu.h for more information.
 * @note The messages file requires fields in a certain format. The format
 * is the prefix followed by a two digit number. The code '00' is the title
 * of the menu, and the code is incremented for each item in the list. This
 * means that the code '01' is the first item, '02' is the second and so
 * forth.
 * @note msg_read() must have been called before calling this function.
 * @see msg_menu()
 * @see menu.h
 * @see msg.h
 */
menu msg_menu(char *prefix,
	      int items,
	      ...);

/**
 * Create a menu from a messages file, with the last entry being writeable.
 * @param prefix the prefix for the menu held in the messages file.
 * @param items the number of items in the messages file.
 * @param store the pointer to the text string store.
 * @param valid the validation string.
 * @param length the maximum length of the string.
 * @param ... two parameters, the first is the menu choose handler function,
 * the second is the sub-menu creation handler function.
 * @return the generated menu.
 * @note This function is prototyped in this way, as the handler functions
 * can have shortcuts if they do not require the full information passed
 * into them. See menu.h for more information.
 * @note The messages file requires fields in a certain format. The format
 * is the prefix followed by a two digit number. The code '00' is the title
 * of the menu, and the code is incremented for each item in the list. This
 * means that the code '01' is the first item, '02' is the second and so
 * forth.
 * @note msg_read() must have been called before calling this function.
 * @see msg_menu()
 * @see menu.h
 * @see msg.h
 */
menu msg_menuwriteable(char *prefix,
		       int items,
		       char *store,
		       char *valid,
		       int length,
		       ...);
#endif

/**
 * Check for a keyboard press
 * @param key the key to check.
 * @return non-zero indicating that the key is pressed.
 * @note The key is not the ASCII code, but the INKEY code.
 */
int check_key(int key);

/**
 * @section Message box flags
 */
#define MB_OK		(1)
#define MB_CANCEL	(2)
#define MB_HILITECANCEL	(4)


#ifdef __cplusplus
}
#endif

#endif
